# pyQuASAR_genotype
Command line tool for genotyping with QuASAR. Infer genotypes from ChIP-seq or
ATAC-seq data.

## Installation

```sh
pip3 install pyQuASAR_genotype
```
or
```sh
pip3 install --user pyQuASAR_genotype
```
